@@ -4,7 +4,6 @@
  * machine independent software sprite routines
  */
 
-/* $Xorg: misprite.c,v 1.4 2001/02/09 02:05:22 xorgcvs Exp $ */
 
 /*
 
@@ -30,7 +29,10 @@ Except as contained in this notice, the name of The Open Group shall not be
 used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 */
-/* $XFree86: xc/programs/Xserver/mi/misprite.c,v 3.10tsi Exp $ */
+
+#ifdef HAVE_DIX_CONFIG_H
+#include <dix-config.h>
+#endif
 
 # include   <X11/X.h>
 # include   <X11/Xproto.h>
@@ -48,9 +50,6 @@ in this Software without prior written authorization from The Open Group.
 # include   "mispritest.h"
 # include   "dixfontstr.h"
 # include   <X11/fonts/fontstruct.h>
-#ifdef HAVE_DIX_CONFIG_H
-#include <dix-config.h>
-#endif
 
 #ifdef RENDER
 # include   "mipict.h"
@@ -99,8 +98,8 @@ static void	    miSpriteComputeSaved(ScreenPtr pScreen);
   ((pScreen)->field = \
    ((miSpriteScreenPtr) (pScreen)->devPrivates[miSpriteScreenIndex].ptr)->field)
 
-#define SCREEN_EPILOGUE(pScreen, field, wrapper)\
-    ((pScreen)->field = wrapper)
+#define SCREEN_EPILOGUE(pScreen, field)\
+    ((pScreen)->field = miSprite##field)
 
 /*
  * pointer-sprite method table
@@ -112,7 +111,7 @@ static void miSpriteSetCursor(ScreenPtr pScreen, CursorPtr pCursor,
 			      int x, int y);
 static void miSpriteMoveCursor(ScreenPtr pScreen, int x, int y);
 
-miPointerSpriteFuncRec miSpritePointerFuncs = {
+_X_EXPORT miPointerSpriteFuncRec miSpritePointerFuncs = {
     miSpriteRealizeCursor,
     miSpriteUnrealizeCursor,
     miSpriteSetCursor,
@@ -300,7 +299,7 @@ miSpriteGetImage (pDrawable, sx, sy, w, h, format, planemask, pdstLine)
     (*pScreen->GetImage) (pDrawable, sx, sy, w, h,
 			  format, planemask, pdstLine);
 
-    SCREEN_EPILOGUE (pScreen, GetImage, miSpriteGetImage);
+    SCREEN_EPILOGUE (pScreen, GetImage);
 }
 
 static void
@@ -346,7 +345,7 @@ miSpriteGetSpans (pDrawable, wMax, ppt, pwidth, nspans, pdstStart)
 
     (*pScreen->GetSpans) (pDrawable, wMax, ppt, pwidth, nspans, pdstStart);
 
-    SCREEN_EPILOGUE (pScreen, GetSpans, miSpriteGetSpans);
+    SCREEN_EPILOGUE (pScreen, GetSpans);
 }
 
 static void
@@ -372,7 +371,7 @@ miSpriteSourceValidate (pDrawable, x, y, width, height)
     if (pScreen->SourceValidate)
 	(*pScreen->SourceValidate) (pDrawable, x, y, width, height);
 
-    SCREEN_EPILOGUE (pScreen, SourceValidate, miSpriteSourceValidate);
+    SCREEN_EPILOGUE (pScreen, SourceValidate);
 }
 
 static void
@@ -395,7 +394,7 @@ miSpriteCopyWindow (WindowPtr pWindow, DDXPointRec ptOldOrg, RegionPtr prgnSrc)
     }
 
     (*pScreen->CopyWindow) (pWindow, ptOldOrg, prgnSrc);
-    SCREEN_EPILOGUE (pScreen, CopyWindow, miSpriteCopyWindow);
+    SCREEN_EPILOGUE (pScreen, CopyWindow);
 }
 
 static void
@@ -414,7 +413,7 @@ miSpriteBlockHandler (i, blockData, pTimeout, pReadmask)
     
     (*pScreen->BlockHandler) (i, blockData, pTimeout, pReadmask);
 
-    SCREEN_EPILOGUE(pScreen, BlockHandler, miSpriteBlockHandler);
+    SCREEN_EPILOGUE(pScreen, BlockHandler);
 
     if (!pPriv->isUp && pPriv->shouldBeUp)
     {
@@ -436,7 +435,7 @@ miSpriteInstallColormap (pMap)
     
     (*pScreen->InstallColormap) (pMap);
 
-    SCREEN_EPILOGUE(pScreen, InstallColormap, miSpriteInstallColormap);
+    SCREEN_EPILOGUE(pScreen, InstallColormap);
 
     pPriv->pInstalledMap = pMap;
     if (pPriv->pColormap != pMap)
@@ -465,7 +464,7 @@ miSpriteStoreColors (pMap, ndef, pdef)
     
     (*pScreen->StoreColors) (pMap, ndef, pdef);
 
-    SCREEN_EPILOGUE(pScreen, StoreColors, miSpriteStoreColors);
+    SCREEN_EPILOGUE(pScreen, StoreColors);
 
     if (pPriv->pColormap == pMap)
     {
@@ -594,7 +593,7 @@ miSpriteSaveDoomedAreas (pWin, pObscured, dx, dy)
 
     (*pScreen->SaveDoomedAreas) (pWin, pObscured, dx, dy);
 
-    SCREEN_EPILOGUE (pScreen, SaveDoomedAreas, miSpriteSaveDoomedAreas);
+    SCREEN_EPILOGUE (pScreen, SaveDoomedAreas);
 }
 
 /*
